@@ -776,6 +776,7 @@ void
 Mail::update_body()
 {
   const auto error = m_parser->get_formatted_error ();
+  TRACEPOINT;
   if (!error.empty())
     {
       if (opt.prefer_html)
@@ -801,7 +802,9 @@ Mail::update_body()
   auto html = m_parser->get_html_body ();
   /** Outlook does not show newlines if \r\r\n is a newline. We replace
     these as apparently some other buggy MUA sends this. */
+  TRACEPOINT;
   find_and_replace (html, "\r\r\n", "\r\n");
+  TRACEPOINT;
   if (opt.prefer_html && !html.empty())
     {
       char *converted = ansi_charset_to_utf8 (m_parser->get_html_charset().c_str(),
@@ -813,6 +816,8 @@ Mail::update_body()
           log_error ("%s:%s: Failed to modify html body of item.",
                      SRCNAME, __func__);
         }
+
+      TRACEPOINT;
       return;
     }
   auto body = m_parser->get_body ();
@@ -820,12 +825,14 @@ Mail::update_body()
   char *converted = ansi_charset_to_utf8 (m_parser->get_body_charset().c_str(),
                                           body.c_str(), body.size());
   int ret = put_oom_string (m_mailitem, "Body", converted ? converted : "");
+  TRACEPOINT;
   xfree (converted);
   if (ret)
     {
       log_error ("%s:%s: Failed to modify body of item.",
                  SRCNAME, __func__);
     }
+  TRACEPOINT;
   return;
 }
 
@@ -1249,7 +1256,9 @@ Mail::get_recipients() const
       TRACEPOINT;
       return nullptr;
     }
-  return get_oom_recipients (recipients);
+  auto ret = get_oom_recipients (recipients);
+  gpgol_release (recipients);
+  return ret;
 }
 
 int
@@ -2121,13 +2130,16 @@ do_locate (LPVOID arg)
                  SRCNAME, __func__, recipient);
     }
   xfree (recipient);
-  do_in_ui_thread (UNKNOWN, NULL);
+  // do_in_ui_thread (UNKNOWN, NULL);
   return 0;
 }
 
+GPGRT_LOCK_DEFINE(uids_searched_lock);
+
 /** Try to locate the keys for all recipients */
 void Mail::locate_keys()
 {
+  gpgrt_lock_lock (&uids_searched_lock);
   char ** recipients = get_recipients ();
 
   if (!recipients)
@@ -2149,6 +2161,7 @@ void Mail::locate_keys()
       xfree (recipients[i]);
     }
   xfree (recipients);
+  gpgrt_lock_unlock (&uids_searched_lock);
 }
 
 bool
