@@ -102,6 +102,14 @@ MailItemEvents::~MailItemEvents()
 
 static bool propchangeWarnShown = false;
 
+static DWORD WINAPI
+do_delayed_locate (LPVOID arg)
+{
+  Sleep(100);
+  do_in_ui_thread (RECIPIENT_ADDED, arg);
+  return 0;
+}
+
 /* The main Invoke function. The return value of this
    function does not appear to have any effect on outlook
    although I have read in an example somewhere that you
@@ -215,6 +223,9 @@ EVENT_SINK_INVOKE(MailItemEvents)
             {
               /* We want to save the mail when it's an smime mail and smime
                  is disabled to revert it. */
+              log_debug ("%s:%s: S/MIME mail but S/MIME is disabled."
+                         " Need save.",
+                         SRCNAME, __func__);
               m_mail->set_needs_save (true);
             }
           break;
@@ -236,13 +247,22 @@ EVENT_SINK_INVOKE(MailItemEvents)
                 {
                   break;
                 }
-              if (!wcscmp (prop_name, L"To") ||
+              if (!wcscmp (prop_name, L"To") /* ||
                   !wcscmp (prop_name, L"BCC") ||
-                  !wcscmp (prop_name, L"CC"))
+                  !wcscmp (prop_name, L"CC")
+                  Testing shows that Outlook always sends these three in a row
+                  */)
                 {
                   if ((m_mail->needs_crypto() & 1))
                     {
-                      m_mail->locate_keys();
+                      /* XXX Racy race. This is a fix for crashes
+                         that happend if a resolved recipient is copied an pasted.
+                         If we then access the recipients object in the Property
+                         Change event we crash. Thus we do the delay dance. */
+                      HANDLE thread = CreateThread (NULL, 0, do_delayed_locate,
+                                                    (LPVOID) m_mail, 0,
+                                                    NULL);
+                      CloseHandle(thread);
                     }
                 }
               break;
@@ -378,6 +398,18 @@ EVENT_SINK_INVOKE(MailItemEvents)
                          SRCNAME, __func__);
               return S_OK;
             }
+
+          if (m_mail->is_crypto_mail () && m_mail->needs_save () &&
+              m_mail->revert ())
+            {
+              /* An error cleaning the mail should not happen normally.
+                 But just in case there is an error we cancel the
+                 write here. */
+              log_debug ("%s:%s: Failed to remove plaintext.",
+                         SRCNAME, __func__);
+              *(parms->rgvarg[0].pboolVal) = VARIANT_TRUE;
+            }
+
           log_debug ("%s:%s: Passing write event.",
                      SRCNAME, __func__);
           m_mail->set_needs_save (false);
