@@ -1468,26 +1468,14 @@ get_mail_from_control (LPDISPATCH ctrl, bool *none_selected)
           // Avoid showing wrong crypto state if we don't have a reading
           // pane. In that case the parser will finish for a mail which is gone
           // and the crypto state will not get updated.
-          LPDISPATCH tableView = get_oom_object (context, "CurrentView");
-          if (!tableView)
+          LPDISPATCH prevEdit = get_oom_object (context, "PreviewPane.WordEditor");
+          gpgol_release (prevEdit);
+          if (!prevEdit)
             {
-              // Woops, should not happen.
-              TRACEPOINT;
               *none_selected = true;
               gpgol_release (mailitem);
               mailitem = nullptr;
             }
-          else
-            {
-              int hasReadingPane = get_oom_bool (tableView, "ShowReadingPane");
-              gpgol_release (tableView);
-              if (!hasReadingPane)
-                {
-                  *none_selected = true;
-                  gpgol_release (mailitem);
-                  mailitem = nullptr;
-                }
-            }
         }
     }
 
